@@ -109,8 +109,8 @@ class TestAllocationCandidatesNoDB(base.TestCase):
             self.context, placement_lib.RequestWideParams(), True)
         areq_lists_by_anchor = {
             "root1": {
-                "": ["r1A", "r1B"],
-                "group1": ["r1g1A", "r1g1B"],
+                "": ["r1A", "r1B",],
+                "group1": ["r1g1A", "r1g1B",],
             },
             "root2": {
                 "": ["r2A"],
